

#include "h/Affichages.h"
#include "h/FctnUSART.h"
#include "h/Parametres.h"
#include "h/Utilitaires.h"


void EnvoyerAuMinitel(unsigned char Donnee)
{
	Delai(100);
	EnvoyerUSART1(Donnee);
	Delai(100);
}

unsigned char RecevoirDuMinitel(void)
{
	/* Masquage du bit de parit */

	return (0x7F & RecevoirUSART1());
}

void AfficheTexteMinitel(const rom char *Texte)
{
	unsigned char k = 0;

	while(Texte[k] != '\0')
	{
		EnvoyerAuMinitel(Texte[k]);
		k++;
	}
}

/* Convertit un nombre dans une base, et afficher le rsultat de cette conversion, sur le Minitel 

Paramtres d'entre :

Valeur - Nombre  afficher.
Base - Base de comptage du nombre  afficher, comprise entre 2 et 16.

Valeur de retour :

Aucune.

*/
void ConvertirEtAfficherMinitel(int Valeur, unsigned char Base)
{
	unsigned char Symboles[16] = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};

	int k = 0;
	static unsigned char Tampon[8];

	do
	{
		Tampon[k] = Symboles[Valeur % Base];
		Valeur = Valeur / Base;
		k++;
	}
	while(Valeur > 0);

	if((Base == 16) && (k == 1))
	{
		EnvoyerAuMinitel('0');
	}
	do
	{
		k--;
		EnvoyerAuMinitel(Tampon[k]);		
	}

	while(k > 0);
}

void AfficheOctetMinitel(unsigned char Octet)
{
	unsigned char k;

	for(k = 8; k > 0; k--)
	{
		if((Octet & (1 << (k - 1))) == 0x00)
		{
			EnvoyerAuMinitel('0');
		}
		else
		{
			EnvoyerAuMinitel('1');
		}
	}
}

void ChoisirUnAttribut(unsigned char CodeAttribut)
{
	EnvoyerAuMinitel(MINITEL_CARACTERE_ECHAPPEMENT);
	EnvoyerAuMinitel(CodeAttribut);
}

void FaireClignoterCaractere(unsigned char X, unsigned char Y, unsigned int NombrePeriodes, unsigned int DelaiDesactive, unsigned int DelaiActive, unsigned char Caractere)
{
	unsigned int k;

	for(k = 0; k < NombrePeriodes; k++)
	{
		PositionnerCurseurMinitel(X, Y);
		EnvoyerAuMinitel(Caractere);
		Delai(DelaiActive);
	
		PositionnerCurseurMinitel(X, Y);
		EnvoyerAuMinitel(' ');
		Delai(DelaiDesactive);
	}
}

void PositionnerCurseurMinitel(unsigned char X, unsigned char Y)
{
	EnvoyerAuMinitel(MINITEL_CARACTERE_DEMANDE_POSITION);
	EnvoyerAuMinitel(X + 0x40);
	EnvoyerAuMinitel(Y + 0x40);
}

unsigned char ChoisirCouleurCaractere(unsigned char CodeCouleurCaractere)
{
	if((CodeCouleurCaractere >= MINITEL_COULEUR_CARACTERE_NOIR) && (CodeCouleurCaractere <= MINITEL_COULEUR_CARACTERE_BLANC))
	{
		ChoisirUnAttribut(CodeCouleurCaractere);

		return 0x00;
	}

	return 0x01;
}

unsigned char ChoisirCouleurFond(unsigned char CodeCouleurFond)
{
	if((CodeCouleurFond >= MINITEL_COULEUR_FOND_NOIR) && (CodeCouleurFond <= MINITEL_COULEUR_FOND_BLANC))
	{
		ChoisirUnAttribut(CodeCouleurFond);

		return 0x00;
	}

	return 0x01;
}

void AfficherDemandeSaisie(unsigned char X, unsigned char Y, const rom char *Texte)
{
	unsigned char k;

	PositionnerCurseurMinitel(Y, X);
	for(k = X; k < 40; k++)	/* Effacement de toute la fin de la ligne Y,
												pour ne pas laisser apparatre l'ventuel texte prcdent */
	{
		EnvoyerAuMinitel(' ');
	}

	PositionnerCurseurMinitel(Y, X);
	AfficheTexteMinitel(Texte);

	PositionnerCurseurMinitel((Y + 1), X);
	EnvoyerAuMinitel('>');
	EnvoyerAuMinitel(MINITEL_CURSEUR_ACTIVE);
}

void EffacerDemandeSaisie(unsigned char X, unsigned char Y, const rom char *Texte)
{
	unsigned char k;

	EnvoyerAuMinitel(MINITEL_CURSEUR_DESACTIVE);

	PositionnerCurseurMinitel((Y + 1), X);
	for(k = X; k < 40; k++)	/* Effacement de toute la fin de la ligne Y + 1,
							pour ne pas laisser apparatre l'ventuel texte prcdent */
	{
		EnvoyerAuMinitel(' ');
	}

	PositionnerCurseurMinitel(Y, X);
	for(k = X; k < 40; k++)	/* Effacement de toute la fin de la ligne Y,
							pour ne pas laisser apparatre l'ventuel texte prcdent */
	{
		EnvoyerAuMinitel(' ');
	}

	PositionnerCurseurMinitel(Y, X);
	AfficheTexteMinitel(Texte);
}

void AfficherResultatJeu(unsigned char Resultat)
{
	if(Resultat == 1)
	{
		PositionnerCurseurMinitel(19, 2);
		ChoisirUnAttribut(MINITEL_LARGEUR_HAUTEUR_DOUBLES);
		AfficheTexteMinitel("VOUS AVEZ GAGNE !\0");	
		EnvoyerAuMinitel(MINITEL_BIP_SONORE);
	}
	else if(Resultat == 2)
	{
		PositionnerCurseurMinitel(19, 2);
		ChoisirUnAttribut(MINITEL_LARGEUR_HAUTEUR_DOUBLES);
		AfficheTexteMinitel("VOUS AVEZ PERDU !\0");	
		EnvoyerAuMinitel(MINITEL_BIP_SONORE);
	}
	ChoisirUnAttribut(MINITEL_LARGEUR_HAUTEUR_NORMALES);
}


