
/* Fonctions permettant
d'utiliser les diffrents composants
relis au bus I2C de l'ensemble */



#include <p18f26j11.h>

#include <delays.h>	/* For delay routines */
#include <i2c.h>	/* Gestion de la communication  l'aide du module  I2C  du PIC18F2610. */

#include "h/FctnI2C.h"
#include "h/Affichages.h"

/* Initialisation du module I2C 1 du PIC18F26J11 en tant que matre

Paramtres d'entre :

Aucun.

Valeur de retour :

Aucune.

*/
void InitI2C1(void)
{
	OpenI2C1(MASTER, SLEW_OFF);

	SSP1ADD = 19;
}

/* Ecriture d'un octet grce au module I2C 1 du PIC18F26J11

Paramtres d'entre :

AdresseI2C - Adresse d'criture, sur le bus I2C, du composant que l'on souhaite crire,
AdresseDonnee - Adresse de la donne  crire
Donnee - Donne  crire.

Valeur de retour :

0 si l'criture s'est effectue correctement, 1 s'il y a eu une erreur lors de l'criture.

*/
unsigned char EcrireDonneeEEPROM(unsigned char AdresseI2C, int AdresseDonnee, unsigned char Donnee)
{
	IdleI2C();	 //Attente du bus OK
	StartI2C();	 //Envoi de message de dbut
	IdleI2C1();	 //Attente de la disponibilit du bus
	putcI2C1(AdresseI2C); //Envoi de l'adresse
	IdleI2C1();	//Attente de la disponibilit du bus
	if(SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C1();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	//Attente de la disponibilit du bus
	putcI2C1((unsigned char)(AdresseDonnee >> 8));	//On crit la valeur
	IdleI2C1();			//Attente de disponibilit du bus
	if(SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C1();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	//Attente de la disponibilit du bus
	putcI2C1((unsigned char)(0x00FF & AdresseDonnee));	//On crit la valeur
	IdleI2C1();			//Attente de disponibilit du bus
	if (SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	//Attente de la disponibilit du bus
	putcI2C1(Donnee);	//On crit la valeur
	IdleI2C1();			//Attente de disponibilit du bus
	if (!SSPCON2bits.ACKSTAT ) //Si on reoit un acquitement, on retourne 0
	{
		StopI2C1();
		return 0x00;
	}

	StopI2C1();

	return 0x01;
}

/* Lectture d'un octet grce au module I2C du PIC18F26J11

Paramtres d'entre :

AdresseI2C - Adresse d'criture, sur le bus I2C 1, du composant que l'on souhaite crire,
AdresseDonnee - Adresse de la donne  lire
*pDonnee - Pointeur vers l'endorit o rcuprer la donne  lire.

Valeur de retour :

0 si la lecture s'est effectue correctement, 1 s'il y a eu une erreur lors de la lecture.

*/
unsigned char LireDonneeEEPROM(unsigned char AdresseI2C, int AdresseDonnee, unsigned char *pDonnee)
{
	IdleI2C1();	 //Attente du bus OK
	StartI2C1();	 //Envoi de message de dbut
	IdleI2C1();	 //Attente de la disponibilit du bus
	putcI2C1(AdresseI2C); //Envoi de l'adresse
	IdleI2C1();	//Attente de la disponibilit du bus
	if(SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C1();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	//Attente de la disponibilit du bus
	putcI2C1((unsigned char)(AdresseDonnee >> 8));	//On crit la valeur
	IdleI2C1();			//Attente de disponibilit du bus
	if(SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C1();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	//Attente de la disponibilit du bus
	putcI2C1((unsigned char)(0x00FF & AdresseDonnee));	//On crit la valeur
	IdleI2C1();			//Attente de disponibilit du bus
	if(SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C1();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	 //Attente du bus OK
	StartI2C1();	 //Envoi de message de dbut
	IdleI2C1();	 //Attente de la disponibilit du bus
	putcI2C1(0x01 | AdresseI2C); //Envoi de l'adresse
	IdleI2C1();	//Attente de la disponibilit du bus
	if(SSPCON2bits.ACKSTAT) //Si AckStat == 1, on n'a pas reu d'acquittement
	{
		StopI2C1();  //Envoi de la condition de stop
		return 0x01;
	}

	IdleI2C1();	//Attente de la disponibilit du bus
	*pDonnee = ReadI2C1(); //Lecture I2C
	NotAckI2C();       //Pas d'acquittement car on lit qu'un seul caractre
	IdleI2C1();
	StopI2C1();          //Envoi du stop


	EnvoyerAuMinitel('D'); 

   return 0x00;
}


