


#include <p18f26j11.h>

#include "h/FctnUSART.h"
#include "h/FctnI2C.h"
#include "h/FctnADC.h"
#include "h/Parametres.h"
#include "h/Affichages.h"
#include "h/Jeu.h"
#include "h/JeuBatonnets.h"
#include "h/JeuMunstermind.h"
#include "h/JeuPendu.h"
#include "h/SemiGraphique.h"
#include "h/Utilitaires.h"


/* Bits de configuration du microcontrleur PIC18F26J11, voir  Help -> Topics -> PIC18 Config Settings  */

#pragma config WDTEN = OFF	/* Watchdog dsactiv */
#pragma config STVREN = OFF	/* Pas de reset du  la pile */
#pragma config XINST = OFF	/* Instruction set extension and Indexed Addressing mode disabled (Legacy mode) */
#pragma config CP0 = OFF	/* Pas de protection du code */
#pragma config OSC = INTOSCPLL	/* Oscillateur interne avec la PLL slectionns */
#pragma config T1DIG = OFF	/* Pas d'utiliseation de l'oscillateur secondaire en cas de dfaillance de l'oscillateur primaire */
#pragma config LPT1OSC = OFF	/* Pas de fonctionnement de l'oscillateur du Timer 1 en mode faible consommation */
#pragma config FCMEN = OFF	/* Fail-Safe Clock dsactiv */
#pragma config IESO = OFF	/* Oscillator Switchover mode dsactiv */
#pragma config WDTPS = 32768	/* Prdiviseur du watchdog normal */
#pragma config DSWDTOSC = T1OSCREF	/* Le watchdog Deep Sleep utilise l'oscillateur RC interne */
#pragma config RTCOSC = T1OSCREF	/* L'horloge temps rel utilise l'oscillateur externe secondaire */
#pragma config DSWDTEN = OFF
#pragma config DSWDTPS = 2	/* Prdiviseur du watchdog Deep Sleep */
#pragma config IOL1WAY = OFF
#pragma config MSSP7B_EN = MSK7



void main(void)
{
	unsigned char k;
	unsigned char Resultat;
	unsigned char L1 = 0x00;
	unsigned char Tour = 0;

	unsigned char Tampon[16];

	/* Configuration de l'oscillateur */

	OSCCON = 0xFF;
	OSCTUNE = 0x00;
	CCP1CON = 0;


	/* Configuration des entres analogiques */

	ADCON1 = 0x0F; 


	/* Configuration des interruptions */

	INTCONbits.GIE = 0;
	INTCONbits.PEIE = 1;
	INTCONbits.INT0IE = 1;
	INTCON2bits.INTEDG0 = 0;
	INTCONbits.INT0IE = 0;
	PIE1bits.RCIE = 1;
	
	/* Configuration du timer 0 */
	
	T0CON = 0b10000000;

	TMR0L = 0x00;
	TMR0H = 0x00;


	/* Configuration du timer 1 */	

	T1CON = 0b00000000;


	/* Configuration des broches gnrales */

	DIRECTION_LED_1 = 0;
	DIRECTION_LED_2 = 0;


	/* Configuration de l'I2C */

	
	DIRECTION_I2C_SCL = 1;
	DIRECTION_I2C_SDA = 1;

	InitI2C1();


	/* Configuration de l'ADC */

	InitADC();

	BROCHE_LED_1 = 0;
	for(k = 0; k < 20; k++)
	{
		BROCHE_LED_1 ^= 1;
		Delai(10000);
	}


	/* Configuration de l'USART 1 */

	DIRECTION_TX_1 = 0;
	DIRECTION_RX_1 = 1;

	while(0)
	{
		PORTCbits.RC6 = PORTCbits.RC7;
		BROCHE_LED_1 = PORTCbits.RC6;
		BROCHE_LED_2 = PORTCbits.RC7;
	}
	InitUSART1();


	/* Configuration de l'USART 2 */

	DIRECTION_TX_2 = 0;
	DIRECTION_RX_2 = 1;

	InitUSART2();


	/* Autorisation globale des interruptions */

	INTCONbits.GIE = 0;


	while(1)
	{
		BROCHE_LED_1 = 1;

		EnvoyerAuMinitel(MINITEL_CARACTERE_EFFACEMENT_ECRAN);
		
		PositionnerCurseurMinitel(3, 1);
		AfficheTexteMinitel("Choix ?\0");
		PositionnerCurseurMinitel(5, 1);
		AfficheTexteMinitel("1 : 3615 BATONNETS\0");
		PositionnerCurseurMinitel(6, 1);
		AfficheTexteMinitel("2 : 3615 MUNSTERMIND\0");
		PositionnerCurseurMinitel(7, 1);
		AfficheTexteMinitel("3 : 3615 PENDU\0");

		do
		{
			k = RecevoirDuMinitel();
		}
		while((k != '1') && (k != '2') && (k != '3'));

		if(k == '1')
		{
			InitJeuBatonnets();
			Tour = 1;
			CompleterRecapitulatifJeuBatonnets(1, Tour);
			do
			{
				BROCHE_LED_1 = Tour;
				Resultat = PrendreJeuBatonnets(Tour);
				Delai(10000);
				Delai(10000);
				Delai(10000);
				Delai(10000);
				if((Resultat == 0) || (Resultat == 2))
				{
					CompleterRecapitulatifJeuBatonnets(0, Tour);
				}
				Tour ^= 1;
			}
			while((Resultat != 1) && (Resultat != 2));

			AfficherResultatJeu(Resultat);
			EffacerDemandeSaisie(2, 22, "APPUYEZ SUR \"ENTREE\" POUR COMMENCER UNE NOUVELLE PARTIE\0");
			while(RecevoirDuMinitel() != MINITEL_CARACTERE_RETOUR_LIGNE);
		}
		else if(k == '2')
		{
			InitJeuMunstermind();
			Tour = 1;

			AccederAuxCodes(0, CODE_A_TROUVER, Tampon);


			/* PositionnerCurseurMinitel(20, 2);
			AfficherUnCode(Tampon); */
			do
			{
				BROCHE_LED_1 = Tour;
				Resultat = PrendreJeuMunstermind(Tour);
				Delai(10000);
				Delai(10000);
				Delai(10000);
				Delai(10000);
				if(Resultat == 0)
				{
					CompleterRecapitulatifJeuMunstermind(Tour);
				}
				Tour = 1;
			}
			while((Resultat != 1) && (Resultat != 2));

			EffacerDemandeSaisie(2, 22, " \0");
			AfficherResultatJeu(Resultat);
			PositionnerCurseurMinitel(20, 2);
			if(Resultat == 1)
			{
				AfficheTexteMinitel("LE CODE ETAIT BIEN : \0");
			}
			else
			{
				AfficheTexteMinitel("LE CODE ETAIT : \0");
			}
			AfficherUnCode(Tampon);

			EffacerDemandeSaisie(2, 22, "APPUYEZ SUR \"ENTREE\" POUR COMMENCER UNE NOUVELLE PARTIE\0");
			while(RecevoirDuMinitel() != MINITEL_CARACTERE_RETOUR_LIGNE);
		}
		else if(k == '3')
		{
			InitJeuPendu();
			Tour = 1;
			AccederAuxMots(0, MOT_A_TROUVER, Tampon);

			/* PositionnerCurseurMinitel(20, 2);
			AfficherMot(Tampon); */
			CompleterRecapitulatifJeuPendu(Tour);
			do
			{
				BROCHE_LED_1 = Tour;
				Resultat = PrendreJeuPendu(Tour);
				Delai(10000);
				Delai(10000);
				Delai(10000);
				Delai(10000);
				if(Resultat == 0)
				{
					CompleterRecapitulatifJeuPendu(Tour);
				}
				Tour = 1;
			}
			while((Resultat != 1) && (Resultat != 2));

			EffacerDemandeSaisie(2, 22, " \0");
			AfficherResultatJeu(Resultat);
			PositionnerCurseurMinitel(20, 2);
			if(Resultat == 1)
			{
				AfficheTexteMinitel("LE MOT ETAIT BIEN : \0");
			}
			else
			{
				AfficheTexteMinitel("LE MOT ETAIT : \0");
			}
			AfficherMot(Tampon);

			EffacerDemandeSaisie(2, 22, "APPUYEZ SUR \"ENTREE\" POUR COMMENCER UNE NOUVELLE PARTIE\0");
			while(RecevoirDuMinitel() != MINITEL_CARACTERE_RETOUR_LIGNE);
		}
		else
		{
			
		}
	}
}



#pragma interrupt InterruptHandler   
void InterruptHandler (void)
{
	unsigned char Tampon;

	/* Interruption provoque par l'USART 1 - MINITEL */
	if((PIE1bits.RCIE == 1) && (PIR1bits.RCIF == 1))
	{
		Tampon = (0x7F & RCREG);
		INTCONbits.GIE = 0;
		RCSTAbits.CREN = 0;

		EnvoyerAuMinitel('C');
		EnvoyerAuMinitel(Tampon);

		RCSTAbits.CREN = 1;
		INTCONbits.GIE = 1;
		PIR1bits.RCIF = 0;
	}
}



#pragma code InterruptVectorHigh = 0x08        /*Placer le code suivant  l'adresse 0x08*/
void InterruptVectorHigh(void)
{
	_asm
		goto InterruptHandler /*Jump To Interrupt Subroutine*/
	_endasm
}


